@@ -1,25 +1,16 @@
 #' @include Solver-proto.R
 NULL
 
-#' Add a Gurobi solver
+#' Add a \emph{Gurobi} solver
 #'
-#' Specify the use of a Gurobi algorithm to solve a
-#' \code{\link{ConservationProblem-class}} object. Requires the \code{gurobi}
-#' package.
-#'
-#' @details
-#'  \href{http://gurobi.com}{Gurobi} is a
-#'     state-of-the-art commercial optimization software with an R package
-#'     interface. It is by far the fastest of the solvers available in this
-#'     package, however, it is also the only solver that is not freely
-#'     available. That said, licenses are available to academics at no cost. The
-#'     \code{gurobi} package is distributed with the Gurobi software suite.
-#'     This solver uses the \code{gurobi} package to solve problems.
+#' Specify that the \emph{Gurobi} software should be used to solve a
+#' conservation planning problem. This function can also be used to
+#' customize the behavior of the solver. It requires the \pkg{gurobi} package.
 #'
 #' @param x \code{\link{ConservationProblem-class}} object.
 #'
 #' @param gap \code{numeric} gap to optimality. This gap is relative when
-#'   solving problems using \code{gurobi}, and will cause the optimizer to
+#'   solving problems using \pkg{gurobi}, and will cause the optimizer to
 #'   terminate when the difference between the upper and lower objective
 #'   function bounds is less than the gap times the upper bound. For example, a
 #'   value of 0.01 will result in the optimizer stopping when the difference
@@ -49,6 +40,17 @@ NULL
 #' @param verbose \code{logical} should information be printed while solving
 #'  optimization problems?
 #'
+#' @details \href{http://gurobi.com}{\emph{Gurobi}} is a
+#'   state-of-the-art commercial optimization software with an R package
+#'   interface. It is by far the fastest of the solvers available in this
+#'   package, however, it is also the only solver that is not freely
+#'   available. That said, licenses are available to academics at no cost. The
+#'   \pkg{gurobi} package is distributed with the \emph{Gurobi} software suite.
+#'   This solver uses the \pkg{gurobi} package to solve problems.
+#'
+#' @return \code{\link{ConservationProblem-class}} object with the solver added
+#'   to it.
+#'
 #' @seealso \code{\link{solvers}}.
 #'
 #' @examples
@@ -62,7 +64,7 @@ NULL
 #'   add_binary_decisions()
 #' \donttest{
 #' # if the package is installed then add solver and generate solution
-#' if (requireNamespace("gurobi", quietly = TRUE)) {
+#' if (require("gurobi")) {
 #'   # specify solver and generate solution
 #'   s <- p %>% add_gurobi_solver(gap = 0.1, presolve = 2, time_limit = 5) %>%
 #'              solve()
@@ -113,7 +115,8 @@ add_gurobi_solver <- function(x, gap = 0.1, time_limit = .Machine$integer.max,
                         upper_limit = parallel::detectCores(TRUE)),
       binary_parameter("first_feasible", first_feasible),
       binary_parameter("verbose", verbose)),
-    solve = function(self, x) {
+    solve = function(self, x, ...) {
+      # create problem
       model <- list(
         modelsense = x$modelsense(),
         vtype = x$vtype(),
@@ -123,6 +126,7 @@ add_gurobi_solver <- function(x, gap = 0.1, time_limit = .Machine$integer.max,
         sense = x$sense(),
         lb = x$lb(),
         ub = x$ub())
+      # create parameters
       p <- list(LogToConsole = as.numeric(self$parameters$get("verbose")),
                 Presolve = self$parameters$get("presolve"),
                 MIPGap = self$parameters$get("gap"),
@@ -131,9 +135,33 @@ add_gurobi_solver <- function(x, gap = 0.1, time_limit = .Machine$integer.max,
                 SolutionLimit = self$parameters$get("first_feasible"))
       if (p$SolutionLimit == 0)
         p$SolutionLimit <- NULL
+      # add extra parameters from portfolio if needed
+      p2 <- list(...)
+      if (length(p2) > 0)
+        p <- append(p, p2)
+      # solve problem
       x <- gurobi::gurobi(model = model, params = p)
+      # round binary variables because default precision is 1e-5
+      b <- model$vtype == "B"
+      if (is.numeric(x$x))
+        x$x[b] <- round(x$x[b])
+      # remove log
       if (file.exists("gurobi.log")) unlink("gurobi.log")
-      return(list(x = x$x, objective = x$objval, status = x$status,
-                  runtime = x$runtime))
+      # extract solutions
+      out <- list(x = x$x, objective = x$objval, status = x$status,
+                 runtime = x$runtime)
+      # add pool if required
+      if (!is.null(p$PoolSearchMode) && is.numeric(x$x) &&
+          isTRUE(length(x$pool) > 1)) {
+        out$pool <- x$pool[-1]
+        for (i in seq_len(length(out$pool))) {
+          out$pool[[i]]$xn[b] <- round(out$pool[[i]]$xn[b])
+          out$pool[[i]]$status <- ifelse(abs(out$pool[[i]]$objval -
+                                             x$objval) < 1e-5,
+                                         "OPTIMAL", "SUBOPTIMAL")
+        }
+      }
+      # return solution
+      return(out)
     }))
 }
