@@ -121,6 +121,8 @@ add_rsymphony_solver <- function(x, gap = 0.1, time_limit = -1,
       if (is.null(x$solution) ||
           names(x$status) %in% c("TM_NO_SOLUTION", "PREP_NO_SOLUTION"))
         return(NULL)
+      if (any(x$solution > 1 | x$solution < 0))
+        stop("infeasible solution returned, try relaxing solver parameters")
       return(list(x = x$solution, objective = x$objval,
                   status = as.character(x$status),
                   runtime = as.double(end_time - start_time,
